@@ -1,4 +1,5 @@
 import os
+import gc
 import re
 import sys
 import tempfile
@@ -10,6 +11,7 @@ from cgi import escape
 
 import transaction
 from lxml.html import fromstring, tostring
+from persistent import Persistent
 from ZODB.POSException import ReadOnlyError
 from ZODB.FileStorage.FileStorage import FileStorage
 from ZODB.DB import DB
@@ -21,6 +23,7 @@ from zope.app.publication.zopepublication import ZopePublication
 from zope.app.folder.folder import Folder
 from zope.app.appsetup.interfaces import DatabaseOpened
 from zope.app.appsetup.bootstrap import bootStrapSubscriber
+from zope.interface import Interface, implementsOnly
 
 from zodbbrowser.standalone import main, serve_forever, stop_serving
 from zodbbrowser import standalone
@@ -73,13 +76,21 @@ class TestsWithoutServer(object):
     """
 
 
+class IMyOwnInterface(Interface):
+    pass
+
+
+class PersistentSubclassThatUsesImplementsOnly(Persistent):
+    implementsOnly(IMyOwnInterface)
+
+
 class TestsWithServer(object):
     """Functional tests with a web app running in the background."""
 
     @classmethod
     def setUp(cls):
         cls.server = ServerController()
-        cls.tempdir = tempfile.mkdtemp('zodbbrowser')
+        cls.tempdir = tempfile.mkdtemp(prefix='test-zodbbrowser-')
         cls.data_fs = os.path.join(cls.tempdir, 'data.fs')
         cls.createTestData()
         cls.server.run(cls.data_fs, '--rw')
@@ -105,6 +116,7 @@ class TestsWithServer(object):
         cls.createTestDataForBrowsing(root_folder)
         cls.createTestDataForRollbacking(root_folder)
         cls.createTestDataForRollbackCanBeCancelled(root_folder)
+        cls.createTestDataForImplementsOnly(root_folder)
         connection.close()
         db.close()
 
@@ -130,18 +142,32 @@ class TestsWithServer(object):
         root_folder['rbcbc'].random_attribute = 'hey'
         transaction.commit()
 
+    @classmethod
+    def createTestDataForImplementsOnly(cls, root_folder):
+        # set up data that implements-only.txt expects
+        root_folder['io'] = Folder()
+        root_folder['io'].crash = PersistentSubclassThatUsesImplementsOnly()
+        transaction.commit()
+
 
 class TestCanCreateEmptyDataFs(unittest.TestCase):
 
     layer = TestsWithoutServer
 
     def setUp(self):
-        self.tempdir = tempfile.mkdtemp('zodbbrowser')
+        self.tempdir = tempfile.mkdtemp(prefix='test-zodbbrowser-')
         self.empty_fs = os.path.join(self.tempdir, 'empty.fs')
         self.server = ServerController()
 
     def tearDown(self):
         self.server.stop()
+        # Make sure we close any open files before we remove the database.
+        # test_cannot_start_in_read_only_mode triggers an exception after the
+        # database has been opened but before it's registered as the IDatabase
+        # utility, so we can't close it explicitly (our code has no references
+        # to the DB; in fact the only refs are the cyclic ones between storages
+        # and databases).
+        gc.collect()
         shutil.rmtree(self.tempdir)
         setup.placelessTearDown()
 
@@ -266,7 +292,7 @@ def fixupWhitespace(element, indent=0, step=2, split_if_longer=38):
         element.tail = None
     element.tail = stripify(element.tail)
     if element.tail and element.tail.startswith(' '):
-        element.tail = '\n' +  ' ' * indent + element.tail.lstrip()
+        element.tail = '\n' + ' ' * indent + element.tail.lstrip()
 
 
 def setUp(test):
@@ -289,10 +315,16 @@ def test_suite():
             'YYYY-MM-DD HH:MM:SS.SSSSSS'),
         (re.compile(r'\d\d\d\d-\d\d-\d\d \d\d:\d\d:\d\d'),
             'YYYY-MM-DD HH:MM:SS'),
+        # zope.app.folder.folder.Folder was moved to zope.site.folder.Folder
+        # but we still support ancient zope versions here
         (re.compile(r'zope\.app\.folder\.folder\.Folder'),
             'zope.site.folder.Folder'),
+        # zope.container 4.0.0 made Folder objects inherit from BTreeContainer
+        # this adds one new attribute that our tests don't expect to see
+        (re.compile(r'<strong>_BTreeContainer__len</strong>'), ''),
     ])
-    optionflags = doctest.REPORT_ONLY_FIRST_FAILURE | doctest.REPORT_NDIFF
+    optionflags = (doctest.REPORT_ONLY_FIRST_FAILURE |
+                   doctest.REPORT_NDIFF | doctest.NORMALIZE_WHITESPACE)
     here = os.path.dirname(__file__)
     for filename in sorted(os.listdir(here)):
         if not filename.endswith('.txt') or filename.startswith('.'):
