@@ -11,7 +11,7 @@ from ZODB.DB import DB
 class RealDatabaseTest(unittest.TestCase):
 
     def setUp(self):
-        self.tmpdir = tempfile.mkdtemp('testzodbbrowser')
+        self.tmpdir = tempfile.mkdtemp(prefix='test-zodbbrowser-')
         self.storage = FileStorage(os.path.join(self.tmpdir, 'Data.fs'))
         self.db = DB(self.storage)
         self.conn = self.db.open()
